/*
 * Copyright (c) 1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *
 * 4. The names "Java Apache Element Construction Set", "Java Apache ECS" and 
 *    "Java Apache Project" must not be used to endorse or promote products 
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called 
 *    "Java Apache Element Construction Set" nor "Java Apache ECS" appear 
 *    in their names without prior written permission of the 
 *    Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *    
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Project. For more information
 * on the Java Apache Project please see <http://java.apache.org/>.
 *
 */
package org.apache.ecs;

/**
    This class creates an Param Element

    @version $Id: Param.java,v 1.3 1999/04/22 01:35:06 stephan Exp $
    @author <a href="mailto:snagy@servletapi.com">Stephan Nagy</a>
    @author <a href="mailto:jon@clearink.com">Jon S. Stevens</a>
*/
public class Param extends SinglePartElement
{
    // Convience variables.

    public final static String REF = "ref";
    public final static String DATA = "data";
    public final static String OBJECT = "object";
    public final static String ref = "ref";
    public final static String data = "data";
    public final static String object = "object";

    /**
        private initializer.
    */
    {
        setElementType("param");
    }

    /**
        Default constructor. use set* methods.
    */
    public Param()
    {
    }

    /**
        Sets the name of this parameter.
        @param name sets the name of this parameter.
    */
    public Param setName(String name)
    {
        addAttribute("name",name);
        return(this);
    }

    /**
        Sets the value of this attribute.
        @param value sets the value attribute.
    */
    public Param setValue(String value)
    {
        addAttribute("value",value);
        return(this);
    }

    /**
        Sets the valuetype of this parameter.
        @param valuetype sets the name of this parameter.<br>
        REF|DATA|OBJECT convience varaibles provided as Param.REF,Param.DATA,Param.OBJECT
    */
    public Param setValueType(String valuetype)
    {
        addAttribute("value",valuetype);
        return(this);
    }

    /**
        Sets the mime type of this object
        @param the mime type of this object
    */
    public Param setType(String cdata)
    {
        addAttribute("type",cdata);
        return(this);
    }
} 